# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from youtube_ti.models.caption import Caption
from typing import Optional, Set
from typing_extensions import Self

class CaptionListResponse(BaseModel):
    """
    CaptionListResponse
    """ # noqa: E501
    etag: Optional[StrictStr] = Field(default=None, description="Etag of this resource.")
    event_id: Optional[StrictStr] = Field(default=None, description="Serialized EventId of the request which produced this response.", alias="eventId")
    items: Optional[List[Caption]] = Field(default=None, description="A list of captions that match the request criteria.")
    kind: Optional[StrictStr] = Field(default='youtube#captionListResponse', description="Identifies what kind of resource this is. Value: the fixed string \"youtube#captionListResponse\".")
    visitor_id: Optional[StrictStr] = Field(default=None, description="The visitorId identifies the visitor.", alias="visitorId")
    __properties: ClassVar[List[str]] = ["etag", "eventId", "items", "kind", "visitorId"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CaptionListResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in items (list)
        _items = []
        if self.items:
            for _item_items in self.items:
                if _item_items:
                    _items.append(_item_items.to_dict())
            _dict['items'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CaptionListResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "etag": obj.get("etag"),
            "eventId": obj.get("eventId"),
            "items": [Caption.from_dict(_item) for _item in obj["items"]] if obj.get("items") is not None else None,
            "kind": obj.get("kind") if obj.get("kind") is not None else 'youtube#captionListResponse',
            "visitorId": obj.get("visitorId")
        })
        return _obj





# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictBytes, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional, Union
from youtube_ti.models.monitor_stream_info import MonitorStreamInfo
from typing import Optional, Set
from typing_extensions import Self

class LiveBroadcastContentDetails(BaseModel):
    """
    Detailed settings of a broadcast.
    """ # noqa: E501
    bound_stream_id: Optional[StrictStr] = Field(default=None, description="This value uniquely identifies the live stream bound to the broadcast.", alias="boundStreamId")
    bound_stream_last_update_time_ms: Optional[datetime] = Field(default=None, description="The date and time that the live stream referenced by boundStreamId was last updated.", alias="boundStreamLastUpdateTimeMs")
    closed_captions_type: Optional[StrictStr] = Field(default=None, alias="closedCaptionsType")
    enable_auto_start: Optional[StrictBool] = Field(default=None, description="This setting indicates whether auto start is enabled for this broadcast. The default value for this property is false. This setting can only be used by Events.", alias="enableAutoStart")
    enable_auto_stop: Optional[StrictBool] = Field(default=None, description="This setting indicates whether auto stop is enabled for this broadcast. The default value for this property is false. This setting can only be used by Events.", alias="enableAutoStop")
    enable_closed_captions: Optional[StrictBool] = Field(default=None, description="This setting indicates whether HTTP POST closed captioning is enabled for this broadcast. The ingestion URL of the closed captions is returned through the liveStreams API. This is mutually exclusive with using the closed_captions_type property, and is equivalent to setting closed_captions_type to CLOSED_CAPTIONS_HTTP_POST.", alias="enableClosedCaptions")
    enable_content_encryption: Optional[StrictBool] = Field(default=None, description="This setting indicates whether YouTube should enable content encryption for the broadcast.", alias="enableContentEncryption")
    enable_dvr: Optional[StrictBool] = Field(default=None, description="This setting determines whether viewers can access DVR controls while watching the video. DVR controls enable the viewer to control the video playback experience by pausing, rewinding, or fast forwarding content. The default value for this property is true. *Important:* You must set the value to true and also set the enableArchive property's value to true if you want to make playback available immediately after the broadcast ends.", alias="enableDvr")
    enable_embed: Optional[StrictBool] = Field(default=None, description="This setting indicates whether the broadcast video can be played in an embedded player. If you choose to archive the video (using the enableArchive property), this setting will also apply to the archived video.", alias="enableEmbed")
    enable_low_latency: Optional[StrictBool] = Field(default=None, description="Indicates whether this broadcast has low latency enabled.", alias="enableLowLatency")
    latency_preference: Optional[StrictStr] = Field(default=None, description="If both this and enable_low_latency are set, they must match. LATENCY_NORMAL should match enable_low_latency=false LATENCY_LOW should match enable_low_latency=true LATENCY_ULTRA_LOW should have enable_low_latency omitted.", alias="latencyPreference")
    mesh: Optional[Union[StrictBytes, StrictStr]] = Field(default=None, description="The mesh for projecting the video if projection is mesh. The mesh value must be a UTF-8 string containing the base-64 encoding of 3D mesh data that follows the Spherical Video V2 RFC specification for an mshp box, excluding the box size and type but including the following four reserved zero bytes for the version and flags.")
    monitor_stream: Optional[MonitorStreamInfo] = Field(default=None, alias="monitorStream")
    projection: Optional[StrictStr] = Field(default=None, description="The projection format of this broadcast. This defaults to rectangular.")
    record_from_start: Optional[StrictBool] = Field(default=None, description="Automatically start recording after the event goes live. The default value for this property is true. *Important:* You must also set the enableDvr property's value to true if you want the playback to be available immediately after the broadcast ends. If you set this property's value to true but do not also set the enableDvr property to true, there may be a delay of around one day before the archived video will be available for playback.", alias="recordFromStart")
    start_with_slate: Optional[StrictBool] = Field(default=None, description="This setting indicates whether the broadcast should automatically begin with an in-stream slate when you update the broadcast's status to live. After updating the status, you then need to send a liveCuepoints.insert request that sets the cuepoint's eventState to end to remove the in-stream slate and make your broadcast stream visible to viewers.", alias="startWithSlate")
    stereo_layout: Optional[StrictStr] = Field(default=None, description="The 3D stereo layout of this broadcast. This defaults to mono.", alias="stereoLayout")
    __properties: ClassVar[List[str]] = ["boundStreamId", "boundStreamLastUpdateTimeMs", "closedCaptionsType", "enableAutoStart", "enableAutoStop", "enableClosedCaptions", "enableContentEncryption", "enableDvr", "enableEmbed", "enableLowLatency", "latencyPreference", "mesh", "monitorStream", "projection", "recordFromStart", "startWithSlate", "stereoLayout"]

    @field_validator('closed_captions_type')
    def closed_captions_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['closedCaptionsTypeUnspecified', 'closedCaptionsDisabled', 'closedCaptionsHttpPost', 'closedCaptionsEmbedded']):
            raise ValueError("must be one of enum values ('closedCaptionsTypeUnspecified', 'closedCaptionsDisabled', 'closedCaptionsHttpPost', 'closedCaptionsEmbedded')")
        return value

    @field_validator('latency_preference')
    def latency_preference_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['latencyPreferenceUnspecified', 'normal', 'low', 'ultraLow']):
            raise ValueError("must be one of enum values ('latencyPreferenceUnspecified', 'normal', 'low', 'ultraLow')")
        return value

    @field_validator('projection')
    def projection_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['projectionUnspecified', 'rectangular', '360', 'mesh']):
            raise ValueError("must be one of enum values ('projectionUnspecified', 'rectangular', '360', 'mesh')")
        return value

    @field_validator('stereo_layout')
    def stereo_layout_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['stereoLayoutUnspecified', 'mono', 'leftRight', 'topBottom']):
            raise ValueError("must be one of enum values ('stereoLayoutUnspecified', 'mono', 'leftRight', 'topBottom')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of LiveBroadcastContentDetails from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of monitor_stream
        if self.monitor_stream:
            _dict['monitorStream'] = self.monitor_stream.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of LiveBroadcastContentDetails from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "boundStreamId": obj.get("boundStreamId"),
            "boundStreamLastUpdateTimeMs": obj.get("boundStreamLastUpdateTimeMs"),
            "closedCaptionsType": obj.get("closedCaptionsType"),
            "enableAutoStart": obj.get("enableAutoStart"),
            "enableAutoStop": obj.get("enableAutoStop"),
            "enableClosedCaptions": obj.get("enableClosedCaptions"),
            "enableContentEncryption": obj.get("enableContentEncryption"),
            "enableDvr": obj.get("enableDvr"),
            "enableEmbed": obj.get("enableEmbed"),
            "enableLowLatency": obj.get("enableLowLatency"),
            "latencyPreference": obj.get("latencyPreference"),
            "mesh": obj.get("mesh"),
            "monitorStream": MonitorStreamInfo.from_dict(obj["monitorStream"]) if obj.get("monitorStream") is not None else None,
            "projection": obj.get("projection"),
            "recordFromStart": obj.get("recordFromStart"),
            "startWithSlate": obj.get("startWithSlate"),
            "stereoLayout": obj.get("stereoLayout")
        })
        return _obj





# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from youtube_ti.models.activity import Activity

class TestActivity(unittest.TestCase):
    """Activity unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Activity:
        """Test Activity
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Activity`
        """
        model = Activity()
        if include_optional:
            return Activity(
                content_details = youtube_ti.models.activity_content_details.ActivityContentDetails(
                    bulletin = youtube_ti.models.activity_content_details_bulletin.ActivityContentDetailsBulletin(
                        resource_id = youtube_ti.models.resource_id.ResourceId(
                            channel_id = '', 
                            kind = '', 
                            playlist_id = '', 
                            video_id = '', ), ), 
                    channel_item = youtube_ti.models.activity_content_details_channel_item.ActivityContentDetailsChannelItem(), 
                    comment = youtube_ti.models.activity_content_details_comment.ActivityContentDetailsComment(), 
                    favorite = youtube_ti.models.activity_content_details_favorite.ActivityContentDetailsFavorite(), 
                    like = youtube_ti.models.activity_content_details_like.ActivityContentDetailsLike(), 
                    playlist_item = youtube_ti.models.activity_content_details_playlist_item.ActivityContentDetailsPlaylistItem(
                        playlist_id = '', 
                        playlist_item_id = '', ), 
                    promoted_item = youtube_ti.models.activity_content_details_promoted_item.ActivityContentDetailsPromotedItem(
                        ad_tag = '', 
                        click_tracking_url = '', 
                        creative_view_url = '', 
                        cta_type = 'ctaTypeUnspecified', 
                        custom_cta_button_text = '', 
                        description_text = '', 
                        destination_url = '', 
                        forecasting_url = [
                            ''
                            ], 
                        impression_url = [
                            ''
                            ], 
                        video_id = '', ), 
                    recommendation = youtube_ti.models.activity_content_details_recommendation.ActivityContentDetailsRecommendation(
                        reason = 'reasonUnspecified', 
                        seed_resource_id = youtube_ti.models.resource_id.ResourceId(
                            channel_id = '', 
                            kind = '', 
                            playlist_id = '', 
                            video_id = '', ), ), 
                    social = youtube_ti.models.activity_content_details_social.ActivityContentDetailsSocial(
                        author = '', 
                        image_url = '', 
                        reference_url = '', 
                        type = 'unspecified', ), 
                    subscription = youtube_ti.models.activity_content_details_subscription.ActivityContentDetailsSubscription(), 
                    upload = youtube_ti.models.activity_content_details_upload.ActivityContentDetailsUpload(
                        video_id = '', ), ),
                etag = '',
                id = '',
                kind = 'youtube#activity',
                snippet = youtube_ti.models.activity_snippet.ActivitySnippet(
                    channel_id = '', 
                    channel_title = '', 
                    description = '', 
                    group_id = '', 
                    published_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    thumbnails = youtube_ti.models.thumbnail_details.ThumbnailDetails(
                        default = youtube_ti.models.thumbnail.Thumbnail(
                            height = 56, 
                            url = '', 
                            width = 56, ), 
                        high = youtube_ti.models.thumbnail.Thumbnail(
                            height = 56, 
                            url = '', 
                            width = 56, ), 
                        maxres = , 
                        medium = , 
                        standard = , ), 
                    title = '', 
                    type = 'typeUnspecified', )
            )
        else:
            return Activity(
        )
        """

    def testActivity(self):
        """Test Activity"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from youtube_ti.models.live_stream_status import LiveStreamStatus

class TestLiveStreamStatus(unittest.TestCase):
    """LiveStreamStatus unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> LiveStreamStatus:
        """Test LiveStreamStatus
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `LiveStreamStatus`
        """
        model = LiveStreamStatus()
        if include_optional:
            return LiveStreamStatus(
                health_status = youtube_ti.models.live_stream_health_status.LiveStreamHealthStatus(
                    configuration_issues = [
                        youtube_ti.models.live_stream_configuration_issue.LiveStreamConfigurationIssue(
                            description = '', 
                            reason = '', 
                            severity = 'info', 
                            type = 'gopSizeOver', )
                        ], 
                    last_update_time_seconds = '', 
                    status = 'good', ),
                stream_status = 'created'
            )
        else:
            return LiveStreamStatus(
        )
        """

    def testLiveStreamStatus(self):
        """Test LiveStreamStatus"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from youtube_ti.models.video_content_details import VideoContentDetails

class TestVideoContentDetails(unittest.TestCase):
    """VideoContentDetails unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> VideoContentDetails:
        """Test VideoContentDetails
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `VideoContentDetails`
        """
        model = VideoContentDetails()
        if include_optional:
            return VideoContentDetails(
                caption = 'true',
                content_rating = youtube_ti.models.content_rating.ContentRating(
                    acb_rating = 'acbUnspecified', 
                    agcom_rating = 'agcomUnspecified', 
                    anatel_rating = 'anatelUnspecified', 
                    bbfc_rating = 'bbfcUnspecified', 
                    bfvc_rating = 'bfvcUnspecified', 
                    bmukk_rating = 'bmukkUnspecified', 
                    catv_rating = 'catvUnspecified', 
                    catvfr_rating = 'catvfrUnspecified', 
                    cbfc_rating = 'cbfcUnspecified', 
                    ccc_rating = 'cccUnspecified', 
                    cce_rating = 'cceUnspecified', 
                    chfilm_rating = 'chfilmUnspecified', 
                    chvrs_rating = 'chvrsUnspecified', 
                    cicf_rating = 'cicfUnspecified', 
                    cna_rating = 'cnaUnspecified', 
                    cnc_rating = 'cncUnspecified', 
                    csa_rating = 'csaUnspecified', 
                    cscf_rating = 'cscfUnspecified', 
                    czfilm_rating = 'czfilmUnspecified', 
                    djctq_rating = 'djctqUnspecified', 
                    djctq_rating_reasons = [
                        'djctqRatingReasonUnspecified'
                        ], 
                    ecbmct_rating = 'ecbmctUnspecified', 
                    eefilm_rating = 'eefilmUnspecified', 
                    egfilm_rating = 'egfilmUnspecified', 
                    eirin_rating = 'eirinUnspecified', 
                    fcbm_rating = 'fcbmUnspecified', 
                    fco_rating = 'fcoUnspecified', 
                    fmoc_rating = 'fmocUnspecified', 
                    fpb_rating = 'fpbUnspecified', 
                    fpb_rating_reasons = [
                        'fpbRatingReasonUnspecified'
                        ], 
                    fsk_rating = 'fskUnspecified', 
                    grfilm_rating = 'grfilmUnspecified', 
                    icaa_rating = 'icaaUnspecified', 
                    ifco_rating = 'ifcoUnspecified', 
                    ilfilm_rating = 'ilfilmUnspecified', 
                    incaa_rating = 'incaaUnspecified', 
                    kfcb_rating = 'kfcbUnspecified', 
                    kijkwijzer_rating = 'kijkwijzerUnspecified', 
                    kmrb_rating = 'kmrbUnspecified', 
                    lsf_rating = 'lsfUnspecified', 
                    mccaa_rating = 'mccaaUnspecified', 
                    mccyp_rating = 'mccypUnspecified', 
                    mcst_rating = 'mcstUnspecified', 
                    mda_rating = 'mdaUnspecified', 
                    medietilsynet_rating = 'medietilsynetUnspecified', 
                    meku_rating = 'mekuUnspecified', 
                    mena_mpaa_rating = 'menaMpaaUnspecified', 
                    mibac_rating = 'mibacUnspecified', 
                    moc_rating = 'mocUnspecified', 
                    moctw_rating = 'moctwUnspecified', 
                    mpaa_rating = 'mpaaUnspecified', 
                    mpaat_rating = 'mpaatUnspecified', 
                    mtrcb_rating = 'mtrcbUnspecified', 
                    nbc_rating = 'nbcUnspecified', 
                    nbcpl_rating = 'nbcplUnspecified', 
                    nfrc_rating = 'nfrcUnspecified', 
                    nfvcb_rating = 'nfvcbUnspecified', 
                    nkclv_rating = 'nkclvUnspecified', 
                    nmc_rating = 'nmcUnspecified', 
                    oflc_rating = 'oflcUnspecified', 
                    pefilm_rating = 'pefilmUnspecified', 
                    rcnof_rating = 'rcnofUnspecified', 
                    resorteviolencia_rating = 'resorteviolenciaUnspecified', 
                    rtc_rating = 'rtcUnspecified', 
                    rte_rating = 'rteUnspecified', 
                    russia_rating = 'russiaUnspecified', 
                    skfilm_rating = 'skfilmUnspecified', 
                    smais_rating = 'smaisUnspecified', 
                    smsa_rating = 'smsaUnspecified', 
                    tvpg_rating = 'tvpgUnspecified', 
                    yt_rating = 'ytUnspecified', ),
                country_restriction = youtube_ti.models.access_policy.AccessPolicy(
                    allowed = True, 
                    exception = [
                        ''
                        ], ),
                definition = 'sd',
                dimension = '',
                duration = '',
                has_custom_thumbnail = True,
                licensed_content = True,
                projection = 'rectangular',
                region_restriction = youtube_ti.models.video_content_details_region_restriction.VideoContentDetailsRegionRestriction(
                    allowed = [
                        ''
                        ], 
                    blocked = [
                        ''
                        ], )
            )
        else:
            return VideoContentDetails(
        )
        """

    def testVideoContentDetails(self):
        """Test VideoContentDetails"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
